summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--chrome/browser/extensions/api/processes/processes_api.cc6
-rw-r--r--chrome/browser/metrics/metrics_service.cc4
-rw-r--r--chrome/browser/performance_monitor/performance_monitor.cc4
-rw-r--r--content/browser/renderer_host/render_widget_host_impl.cc2
-rw-r--r--content/public/browser/notification_types.h4
5 files changed, 10 insertions, 10 deletions
diff --git a/chrome/browser/extensions/api/processes/processes_api.cc b/chrome/browser/extensions/api/processes/processes_api.cc
index 279619b..16e423b 100644
--- a/chrome/browser/extensions/api/processes/processes_api.cc
+++ b/chrome/browser/extensions/api/processes/processes_api.cc
@@ -220,7 +220,7 @@ ProcessesEventRouter::ProcessesEventRouter(Profile* profile)
model_ = TaskManager::GetInstance()->model();
model_->AddObserver(this);
- registrar_.Add(this, content::NOTIFICATION_RENDERER_PROCESS_HANG,
+ registrar_.Add(this, content::NOTIFICATION_RENDER_WIDGET_HOST_HANG,
content::NotificationService::AllSources());
registrar_.Add(this, content::NOTIFICATION_RENDERER_PROCESS_CLOSED,
content::NotificationService::AllSources());
@@ -229,7 +229,7 @@ ProcessesEventRouter::ProcessesEventRouter(Profile* profile)
ProcessesEventRouter::~ProcessesEventRouter() {
#if defined(ENABLE_TASK_MANAGER)
- registrar_.Remove(this, content::NOTIFICATION_RENDERER_PROCESS_HANG,
+ registrar_.Remove(this, content::NOTIFICATION_RENDER_WIDGET_HOST_HANG,
content::NotificationService::AllSources());
registrar_.Remove(this, content::NOTIFICATION_RENDERER_PROCESS_CLOSED,
content::NotificationService::AllSources());
@@ -275,7 +275,7 @@ void ProcessesEventRouter::Observe(
const content::NotificationDetails& details) {
switch (type) {
- case content::NOTIFICATION_RENDERER_PROCESS_HANG:
+ case content::NOTIFICATION_RENDER_WIDGET_HOST_HANG:
ProcessHangEvent(
content::Source<content::RenderWidgetHost>(source).ptr());
break;
diff --git a/chrome/browser/metrics/metrics_service.cc b/chrome/browser/metrics/metrics_service.cc
index 81103be..aaaf458 100644
--- a/chrome/browser/metrics/metrics_service.cc
+++ b/chrome/browser/metrics/metrics_service.cc
@@ -656,7 +656,7 @@ void MetricsService::SetUpNotifications(
content::NotificationService::AllSources());
registrar->Add(observer, content::NOTIFICATION_RENDERER_PROCESS_CLOSED,
content::NotificationService::AllSources());
- registrar->Add(observer, content::NOTIFICATION_RENDERER_PROCESS_HANG,
+ registrar->Add(observer, content::NOTIFICATION_RENDER_WIDGET_HOST_HANG,
content::NotificationService::AllSources());
registrar->Add(observer, chrome::NOTIFICATION_OMNIBOX_OPENED_URL,
content::NotificationService::AllSources());
@@ -719,7 +719,7 @@ void MetricsService::Observe(int type,
}
break;
- case content::NOTIFICATION_RENDERER_PROCESS_HANG:
+ case content::NOTIFICATION_RENDER_WIDGET_HOST_HANG:
LogRendererHang();
break;
diff --git a/chrome/browser/performance_monitor/performance_monitor.cc b/chrome/browser/performance_monitor/performance_monitor.cc
index aa96324..c539d09 100644
--- a/chrome/browser/performance_monitor/performance_monitor.cc
+++ b/chrome/browser/performance_monitor/performance_monitor.cc
@@ -239,7 +239,7 @@ void PerformanceMonitor::RegisterForNotifications() {
content::NotificationService::AllSources());
// Crashes
- registrar_.Add(this, content::NOTIFICATION_RENDERER_PROCESS_HANG,
+ registrar_.Add(this, content::NOTIFICATION_RENDER_WIDGET_HOST_HANG,
content::NotificationService::AllSources());
registrar_.Add(this, content::NOTIFICATION_RENDERER_PROCESS_CLOSED,
content::NotificationService::AllSources());
@@ -594,7 +594,7 @@ void PerformanceMonitor::Observe(int type,
content::Details<Extension>(details).ptr());
break;
}
- case content::NOTIFICATION_RENDERER_PROCESS_HANG: {
+ case content::NOTIFICATION_RENDER_WIDGET_HOST_HANG: {
std::string url;
content::RenderWidgetHost* widget =
content::Source<content::RenderWidgetHost>(source).ptr();
diff --git a/content/browser/renderer_host/render_widget_host_impl.cc b/content/browser/renderer_host/render_widget_host_impl.cc
index 57f8f8f..d8c0b05 100644
--- a/content/browser/renderer_host/render_widget_host_impl.cc
+++ b/content/browser/renderer_host/render_widget_host_impl.cc
@@ -1392,7 +1392,7 @@ void RenderWidgetHostImpl::CheckRendererIsUnresponsive() {
// OK, looks like we have a hung renderer!
NotificationService::current()->Notify(
- NOTIFICATION_RENDERER_PROCESS_HANG,
+ NOTIFICATION_RENDER_WIDGET_HOST_HANG,
Source<RenderWidgetHost>(this),
NotificationService::NoDetails());
is_unresponsive_ = true;
diff --git a/content/public/browser/notification_types.h b/content/public/browser/notification_types.h
index 4e0eee1..3366f16 100644
--- a/content/public/browser/notification_types.h
+++ b/content/public/browser/notification_types.h
@@ -166,10 +166,10 @@ enum NotificationType {
// This may get sent along with RENDERER_PROCESS_TERMINATED.
NOTIFICATION_RENDERER_PROCESS_CLOSED,
// Indicates that a render process has become unresponsive for a period of
// time. The source will be the RenderWidgetHost that corresponds to the
// hung view, and no details are expected.
- NOTIFICATION_RENDERER_PROCESS_HANG,
+ NOTIFICATION_RENDER_WIDGET_HOST_HANG,
// This is sent when a RenderWidgetHost is being destroyed. The source is
// the RenderWidgetHost, the details are not used.
@@ -166,10 +166,10 @@ enum NotificationType {
// This may get sent along with RENDERER_PROCESS_TERMINATED.
NOTIFICATION_RENDERER_PROCESS_CLOSED,
- // Indicates that a render process has become unresponsive for a period of
+ // Indicates that a RenderWidgetHost has become unresponsive for a period of
// time. The source will be the RenderWidgetHost that corresponds to the
// hung view, and no details are expected.